pub struct ScriptTypeRegistration(/* private fields */);Implementations
Sourceimpl ScriptTypeRegistration
impl ScriptTypeRegistration
pub fn new(arc: Arc<TypeRegistration>) -> Self
pub fn short_name(&self) -> &str
pub fn type_name(&self) -> &'static str
Methods from Deref<Target = TypeRegistration>
Sourcepub fn type_info(&self) -> &'static TypeInfo
pub fn type_info(&self) -> &'static TypeInfo
Returns a reference to the registration’s TypeInfo
Sourcepub fn data<T>(&self) -> Option<&T>where
T: TypeData,
pub fn data<T>(&self) -> Option<&T>where
T: TypeData,
Returns a reference to the value of type T in this registration’s
type data.
Returns None if no such value exists.
For a dynamic version of this method, see data_by_id.
Sourcepub fn data_by_id(&self, type_id: TypeId) -> Option<&(dyn TypeData + 'static)>
pub fn data_by_id(&self, type_id: TypeId) -> Option<&(dyn TypeData + 'static)>
Sourcepub fn contains<T>(&self) -> boolwhere
T: TypeData,
pub fn contains<T>(&self) -> boolwhere
T: TypeData,
Returns true if this registration contains the given type data.
For a dynamic version of this method, see contains_by_id.
Sourcepub fn contains_by_id(&self, type_id: TypeId) -> bool
pub fn contains_by_id(&self, type_id: TypeId) -> bool
Sourcepub fn iter(&self) -> impl ExactSizeIterator
pub fn iter(&self) -> impl ExactSizeIterator